pub enum OldRequestStatus<AccountId, Balance> {
Unrequested {
deposit: (AccountId, Balance),
len: u32,
},
Requested {
deposit: Option<(AccountId, Balance)>,
count: u32,
len: Option<u32>,
},
}Expand description
A type to note whether a preimage is owned by a user or the system.
Variants
Unrequested
The associated preimage has not yet been requested by the system. The given deposit (if some) is being held until either it becomes requested or the user retracts the preimage.
Requested
There are a non-zero number of outstanding requests for this hash by this chain. If there
is a preimage registered, then len is Some and it may be removed iff this counter
becomes zero.