pub enum Call<T: Config> {
note_preimage {
bytes: Vec<u8>,
},
unnote_preimage {
hash: T::Hash,
},
request_preimage {
hash: T::Hash,
},
unrequest_preimage {
hash: T::Hash,
},
ensure_updated {
hashes: Vec<T::Hash>,
},
// some variants omitted
}Expand description
Contains a variant per dispatchable extrinsic that this pallet has.
Variants
note_preimage
Register a preimage on-chain.
If the preimage was previously requested, no fees or deposits are taken for providing the preimage. Otherwise, a deposit is taken proportional to the size of the preimage.
unnote_preimage
Clear an unrequested preimage from the runtime storage.
If len is provided, then it will be a much cheaper operation.
hash: The hash of the preimage to be removed from the store.len: The length of the preimage ofhash.
request_preimage
Request a preimage be uploaded to the chain without paying any fees or deposits.
If the preimage requests has already been provided on-chain, we unreserve any deposit a user may have paid, and take the control of the preimage out of their hands.
unrequest_preimage
Clear a previously made request for a preimage.
NOTE: THIS MUST NOT BE CALLED ON hash MORE TIMES THAN request_preimage.
ensure_updated
Ensure that the bulk of pre-images is upgraded.
The caller pays no fee if at least 90% of pre-images were successfully updated.
Implementations
Sourceimpl<T: Config> Call<T>
impl<T: Config> Call<T>
Sourcepub fn new_call_variant_note_preimage(bytes: Vec<u8>) -> Self
pub fn new_call_variant_note_preimage(bytes: Vec<u8>) -> Self
Create a call with the variant note_preimage.
Sourcepub fn new_call_variant_unnote_preimage(hash: T::Hash) -> Self
pub fn new_call_variant_unnote_preimage(hash: T::Hash) -> Self
Create a call with the variant unnote_preimage.
Sourcepub fn new_call_variant_request_preimage(hash: T::Hash) -> Self
pub fn new_call_variant_request_preimage(hash: T::Hash) -> Self
Create a call with the variant request_preimage.
Sourcepub fn new_call_variant_unrequest_preimage(hash: T::Hash) -> Self
pub fn new_call_variant_unrequest_preimage(hash: T::Hash) -> Self
Create a call with the variant unrequest_preimage.
Sourcepub fn new_call_variant_ensure_updated(hashes: Vec<T::Hash>) -> Self
pub fn new_call_variant_ensure_updated(hashes: Vec<T::Hash>) -> Self
Create a call with the variant ensure_updated.